==> sunbird-0.2-source.tar.bz2: mozilla/extensions/java/xpcom/tests/Foo.java <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Java XPCOM Bindings.
 *
 * The Initial Developer of the Original Code is
 * IBM Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2004
 * IBM Corporation. All Rights Reserved.
 *
 * Contributor(s):
 *   Javier Pedemonte (jhpedemonte@gmail.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

import org.mozilla.xpcom.*;

public class Foo implements IFoo {

  static int gCount;
  int mID;

  public Foo(int aID)
  {
    mID = aID;
    ++gCount;
    System.out.println("init: " + mID + " (" + this.hashCode() + "), " +
                       gCount +" total");
  }

  // nsISupports implementation
  public nsISupports queryInterface(String aIID)
  {
    return XPCOM.queryInterface(this, aIID);
  }

  // IFoo implementation
  public int getId()
  {
    return mID;
  }

  protected void finalize() throws Throwable
  {
    --gCount;
    System.out.println("destruct: " + mID + " (" + this.hashCode() + "), " +
                       gCount +" remain");
  }
}

==> sunbird-0.3.1.source.tar.bz2: mozilla/extensions/java/xpcom/tests/Foo.java <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Java XPCOM Bindings.
 *
 * The Initial Developer of the Original Code is IBM Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2006
 * IBM Corporation. All Rights Reserved.
 *
 * Contributor(s):
 *   Javier Pedemonte (jhpedemonte@gmail.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

import org.mozilla.xpcom.Mozilla;
import org.mozilla.xpcom.nsISupports;

public class Foo implements nsISupports {

  static int gCount;
  int mID;

  public Foo(int aID)
  {
    mID = aID;
    ++gCount;
    System.out.println("init: " + mID + " (" +
                       Integer.toHexString(this.hashCode()) + "), " +
                       gCount +" total");
  }

  // nsISupports implementation
  public nsISupports queryInterface(String aIID)
  {
    return Mozilla.queryInterface(this, aIID);
  }

  public int getId()
  {
    return mID;
  }

  protected void finalize() throws Throwable
  {
    --gCount;
    System.out.println("destruct: " + mID + " (" +
                       Integer.toHexString(this.hashCode()) + "), " +
                       gCount +" remain");
  }
}
